﻿using System;
using System.Collections;
using System.Collections.Generic;
using Android.App;
using Android.Views;
using Android.Widget;
using Android.OS;
using Android.Support.V7.Widget;
using Com.Telerik.Widget.List;

namespace ListViewPlayground
{
    [Activity(Label = "ListViewPlayground", MainLauncher = true, Icon = "@drawable/icon")]
    public class MainActivity : Activity
    {
        protected override void OnCreate(Bundle bundle)
        {
            base.OnCreate(bundle);

            // Set our view from the "main" layout resource
            SetContentView(Resource.Layout.Main);

            RadListView listView = FindViewById<RadListView>(Resource.Id.listView);
            
            ListViewAdapter listViewAdapter = new ListViewAdapter(GetListOfCities());
            listView.SetAdapter(listViewAdapter);

            CityAdapter cityAdapter = new CityAdapter(GetListOfCities());
            listView.SetAdapter(cityAdapter);

        }

        private List<City> GetListOfCities()
        {
            List<City> cities = new List<City>
            {
                new City("London", "United Kingdom"),
                new City("Berlin", "Germany"),
                new City("Madrid", "Spain"),
                new City("Rome", "Italy"),
                new City("Paris", "France"),
                new City("Hamburg", "Germany"),
                new City("Barcelona", "Spain"),
                new City("Munich", "Germany"),
                new City("Milan", "Italy"),
                new City("Cologne", "Germany")
            };
            return cities;
        }
    }

    public class City
    {
        public string Name { get; set; }
        public string Country { get; set; }

        public City(string name, string country)
        {
            Name = name;
            Country = country;
        }

        public override string ToString()
        {
            return $"{Name} ({Country})";
        }
    }

    public class CityAdapter : ListViewAdapter
    {
        public CityAdapter(IList items)
            : base(items)
        {
        }

        public override RecyclerView.ViewHolder OnCreateViewHolder(ViewGroup parent, int viewType)
        {
            LayoutInflater inflater = LayoutInflater.From(parent.Context);
            View view = inflater.Inflate(Resource.Layout.CityListItem, parent, false);
            return new CityViewHolder(view);
        }

        public override void OnBindListViewHolder(ListViewHolder holder, int position)
        {
            CityViewHolder viewHolder = (CityViewHolder)holder;
            City city = (City)Items[position];
            viewHolder.nameView.Text = city.Name;
            viewHolder.countryView.Text = city.Country;
        }

        public class CityViewHolder : ListViewHolder
        {
            public TextView nameView;
            public TextView countryView;

            public CityViewHolder(View itemView)
                : base(itemView)
            {

                nameView = (TextView)itemView.FindViewById(Resource.Id.nameView);
                countryView = (TextView)itemView.FindViewById(Resource.Id.countryView);
            }
        }
    }
    
}

